@@ -4,10 +4,11 @@
 # or https://github.com/scikit-hep/particle for details.
 
 
-import sys
-from typing import Tuple
+from __future__ import annotations
 
-# Direct access to other ID classes
+import sys
+
+from .corsika import Corsika7ID
 from .geant import Geant3ID
 
 # Direct access to Particle literals
@@ -30,6 +31,7 @@ from .particle import latex_to_html_name, lifetime_to_width, width_to_lifetime
 
 __all__ = (
     "Charge",
+    "Corsika7ID",
     "Geant3ID",
     "Inv",
     "InvalidParticle",
@@ -47,5 +49,5 @@ __all__ = (
 )
 
 
-def __dir__() -> Tuple[str, ...]:
+def __dir__() -> tuple[str, ...]:
     return __all__
