@@ -4,8 +4,9 @@
 # or https://github.com/scikit-hep/particle for details.
 
 
-from typing import Tuple
+from __future__ import annotations
 
+from .corsika import Corsika72PDGIDBiMap
 from .evtgen import EvtGen2PDGNameMap, EvtGenName2PDGIDBiMap, PDG2EvtGenNameMap
 from .geant import Geant2PDGIDBiMap
 from .pythia import Pythia2PDGIDBiMap
@@ -16,8 +17,9 @@ __all__ = (
     "PDG2EvtGenNameMap",
     "Geant2PDGIDBiMap",
     "Pythia2PDGIDBiMap",
+    "Corsika72PDGIDBiMap",
 )
 
 
-def __dir__() -> Tuple[str, ...]:
+def __dir__() -> tuple[str, ...]:
     return __all__
