@@ -4,23 +4,13 @@
 # or https://github.com/scikit-hep/particle for details.
 
 
+from __future__ import annotations
+
+import contextlib
 import csv
 import sys
 from collections.abc import Mapping
-from typing import (
-    Any,
-    Callable,
-    Dict,
-    Generic,
-    Iterator,
-    Optional,
-    TextIO,
-    Tuple,
-    Type,
-    TypeVar,
-    Union,
-    overload,
-)
+from typing import Any, Callable, Generic, Iterator, TextIO, TypeVar, Union, overload
 
 from .. import data
 from ..exceptions import MatchingIDNotFound
@@ -35,10 +25,10 @@ B_conv = Callable[[str], Union[B, int]]
 class BiMap(Generic[A, B]):
     def __init__(
         self,
-        class_A: Type[A],
-        class_B: Type[B],
-        converters: Tuple[A_conv, B_conv] = (int, int),  # type: ignore[type-arg]
-        filename: Optional[StringOrIO] = None,
+        class_A: type[A],
+        class_B: type[B],
+        converters: tuple[A_conv, B_conv] = (int, int),  # type: ignore[type-arg]
+        filename: StringOrIO | None = None,
     ) -> None:
         """
         Bi-bidirectional map class.
@@ -80,8 +70,8 @@ class BiMap(Generic[A, B]):
         >>> bimap = BiMap(PDGID, PythiaID, filename=filename)
         """
 
-        self.class_A: Type[A] = class_A
-        self.class_B: Type[B] = class_B
+        self.class_A: type[A] = class_A
+        self.class_B: type[B] = class_B
 
         name_A = self.class_A.__name__.upper()
         name_B = self.class_B.__name__.upper()
@@ -95,7 +85,7 @@ class BiMap(Generic[A, B]):
         elif isinstance(filename, HasOpen):
             file_object = filename.open()
         else:
-            file_object = open(filename)  # type: ignore[arg-type]
+            file_object = open(filename, encoding="utf_8")  # type: ignore[arg-type]
 
         with file_object as _f:
             self._to_map = {
@@ -118,15 +108,11 @@ class BiMap(Generic[A, B]):
 
     def __getitem__(self, value: Any) -> Any:
         if isinstance(value, self.class_B):
-            try:
+            with contextlib.suppress(KeyError):
                 return self.class_A(self._to_map[value])  # type: ignore[call-arg]
-            except KeyError:
-                pass
         elif isinstance(value, self.class_A):
-            try:
+            with contextlib.suppress(KeyError):
                 return self.class_B(self._from_map[value])  # type: ignore[call-arg]
-            except KeyError:
-                pass
 
         name_A = self.class_A.__name__
         name_B = self.class_B.__name__
@@ -147,9 +133,9 @@ class BiMap(Generic[A, B]):
 def DirectionalMaps(
     name_A: str,
     name_B: str,
-    converters: Tuple[Callable[[str], str], Callable[[str], str]] = (str, str),
-    filename: Optional[StringOrIO] = None,
-) -> Tuple["DirectionalMap", "DirectionalMap"]:
+    converters: tuple[Callable[[str], str], Callable[[str], str]] = (str, str),
+    filename: StringOrIO | None = None,
+) -> tuple[DirectionalMap, DirectionalMap]:
     """
     Directional map class providing a to and from mapping.
 
@@ -189,7 +175,7 @@ def DirectionalMaps(
     elif isinstance(filename, HasRead):
         file_object = filename
     else:
-        file_object = open(filename)  # type: ignore[arg-type]
+        file_object = open(filename, encoding="utf_8")  # type: ignore[arg-type]
 
     with file_object as _f:
         skipinitialspace = True
@@ -225,7 +211,8 @@ else:
 
 
 class DirectionalMap(StrStrMapping):
-    def __init__(self, name_A: str, name_B: str, map: Dict[str, str]) -> None:
+    # pylint: disable-next=redefined-builtin
+    def __init__(self, name_A: str, name_B: str, map: dict[str, str]) -> None:
         """
         Directional map class providing a A -> B mapping.
 
