@@ -3,12 +3,16 @@
 # Distributed under the 3-clause BSD license, see accompanying file LICENSE
 # or https://github.com/scikit-hep/particle for details.
 
+from __future__ import annotations
+
 import sys
 
 if sys.version_info < (3, 9):
     import importlib_resources as resources
 else:
-    import importlib.resources as resources
+    from importlib import resources
+
+__all__ = ["basepath"]
 
 
 basepath = resources.files(__name__)
