@@ -4,12 +4,12 @@
 # or https://github.com/scikit-hep/particle for details.
 
 
-from typing import Tuple
+from __future__ import annotations
 
 from .geant3id import Geant3ID
 
 __all__ = ("Geant3ID",)
 
 
-def __dir__() -> Tuple[str, ...]:
+def __dir__() -> tuple[str, ...]:
     return __all__
