@@ -13,8 +13,10 @@ follows the PDG rules, hence uses the standard PDG IDs.
 """
 
 
+from __future__ import annotations
+
 import csv
-from typing import Type, TypeVar
+from typing import TypeVar
 
 from .. import data
 from ..exceptions import MatchingIDNotFound
@@ -49,7 +51,7 @@ class Geant3ID(int):
     __slots__ = ()  # Keep PythiaID a slots based class
 
     @classmethod
-    def from_pdgid(cls: Type[Self], pdgid: int) -> Self:
+    def from_pdgid(cls: type[Self], pdgid: int) -> Self:
         """
         Constructor from a PDGID.
         """
