@@ -3,7 +3,7 @@
 # Distributed under the 3-clause BSD license, see accompanying file LICENSE
 # or https://github.com/scikit-hep/particle for details.
 
-from typing import Tuple
+from __future__ import annotations
 
 from .converters import LHCbName2PDGIDBiMap
 from .functions import from_lhcb_name, to_lhcb_name
@@ -15,5 +15,5 @@ __all__ = (
 )
 
 
-def __dir__() -> Tuple[str, ...]:
+def __dir__() -> tuple[str, ...]:
     return __all__
