@@ -8,7 +8,7 @@ This is a conversion file, not part of the public API.
 
 The default CSV files can be updated directly using the command:
 
-    >>> python -m particle.particle.convert regenerate 2021 <version_number>    # doctest: +SKIP
+    >>> python -m particle.particle.convert regenerate 2022 <version_number>    # doctest: +SKIP
 
 A custom fwf file and LaTeX file can be converted into the CSV format using:
 
@@ -33,7 +33,7 @@ combined with one or more LaTeX files describing the pair (PDG ID, LaTeX name):
 
 You can also read in a modern "standard" file (this will produce fewer columns):
 
-    >>> ext_table = get_from_pdg_mcd('particle/data/mass_width_2021.mcd')
+    >>> ext_table = get_from_pdg_mcd('particle/data/mass_width_2022.mcd')
 
 A utility is even provided to use the modern table to update the full table:
 
@@ -50,10 +50,13 @@ When you are done, you can save one or more of the tables:
 
 """
 
+from __future__ import annotations
+
 import os
 from datetime import date
 from io import StringIO
-from typing import Any, Callable, Dict, Iterable, List, Optional, TextIO, Tuple, TypeVar
+from pathlib import Path
+from typing import Any, Callable, Iterable, TextIO, TypeVar
 
 import numpy as np
 import pandas as pd
@@ -82,7 +85,7 @@ __all__ = (
 )
 
 
-def __dir__() -> Tuple[str, ...]:
+def __dir__() -> tuple[str, ...]:
     return __all__
 
 
@@ -103,7 +106,8 @@ def filter_file(fileobject: StringOrIO) -> TextIO:
 
     if not hasattr(fileobject, "read"):
         assert isinstance(fileobject, str)
-        fileobject = open(fileobject, encoding="utf-8")
+        with open(fileobject, encoding="utf-8") as f:
+            return filter_file(f)
 
     assert not isinstance(fileobject, (str, Traversable))
 
@@ -114,9 +118,6 @@ def filter_file(fileobject: StringOrIO) -> TextIO:
             stream.write(line)
     stream.seek(0)
 
-    if not fileobject.closed:
-        fileobject.close()
-
     return stream
 
 
@@ -142,9 +143,9 @@ def get_from_pdg_extended(
     >>> full_table = get_from_pdg_extended('particle/data/mass_width_2008.fwf',
     ...                                    ['particle/data/pdgid_to_latexname.csv'])
     """
-    "Read a file, plus a list of LaTeX files, to produce a pandas DataFrame with particle information"
 
-    def unmap(mapping: Dict[str, T]) -> Callable[[str], T]:
+    # Read a file, plus a list of LaTeX files, to produce a pandas DataFrame with particle information
+    def unmap(mapping: dict[str, T]) -> Callable[[str], T]:
         return lambda x: mapping[x.strip()]
 
     # Convert each column from text to appropriate data type
@@ -266,11 +267,11 @@ def sort_particles(table: pd.DataFrame) -> None:
 
 def get_from_pdg_mcd(filename: StringOrIO) -> pd.DataFrame:
     """
-    Reads in a current-style PDG .mcd file (mass_width_2021.mcd file tested).
+    Reads in a current-style PDG .mcd file (mass_width_2022.mcd file tested).
 
     Example
     -------
-    >>> mcd_table = get_from_pdg_mcd('particle/data/mass_width_2021.mcd')
+    >>> mcd_table = get_from_pdg_mcd('particle/data/mass_width_2022.mcd')
     """
 
     # The format here includes the space before a column
@@ -332,7 +333,7 @@ def get_from_pdg_mcd(filename: StringOrIO) -> pd.DataFrame:
         d["ID"] = d[name].astype(int)
         nc = d.NameCharge.str.split(expand=True)
         d["Name"] = nc[0]
-        abcd = nc[1].str.split(",", 4, expand=True)
+        abcd = nc[1].str.split(pat=",", n=4, expand=True)
         d["charge"] = abcd[i]
         d.set_index("ID", inplace=True)
         ds_list.append(d)
@@ -357,7 +358,7 @@ def update_from_mcd(
 
     Example
     -------
-    >>> new_table = update_from_mcd('mass_width_2008.fwf', 'mass_width_2021.mcd')    # doctest: +SKIP
+    >>> new_table = update_from_mcd('mass_width_2008.fwf', 'mass_width_2022.mcd')    # doctest: +SKIP
     """
 
     full_table = full_table.copy()
@@ -370,7 +371,10 @@ def update_from_mcd(
 
 
 def produce_files(
-    particle2008: str, particle2021: str, version: str, year: str
+    particle2008: str | Path,  # pylint: disable=unused-argument
+    particle2022: str | Path,
+    version: str,
+    year: str,
 ) -> None:
     "This produces listed output files from all input files."
 
@@ -386,7 +390,6 @@ def produce_files(
     full_table.drop([30221, 100223, 5132, 5232], axis=0, inplace=True)
 
     # No longer write out the particle2008.csv file, which nobody should use
-    # particle2008 = str(particle2008)  # Conversion to handle pathlib on Python < 3.6.1
     # with open(particle2008, "w", newline="\n", encoding="utf-8") as f:
     # f.write(version_header(particle2008, version))
     # full_table.to_csv(f, float_format="%.12g")
@@ -412,9 +415,8 @@ def produce_files(
 
     new_table = update_from_mcd(full_table, ext_table)
 
-    particle2021 = str(particle2021)  # Conversion to handle pathlib on Python < 3.6.1
-    with open(particle2021, "w", newline="\n", encoding="utf-8") as f:
-        f.write(version_header(particle2021, version))
+    with open(particle2022, "w", newline="\n", encoding="utf-8") as f:
+        f.write(version_header(str(particle2022), version))
         new_table.to_csv(f, float_format="%.12g")
 
 
@@ -435,8 +437,8 @@ def main(version: str, year: str) -> None:
     produce_files(particle2008, particlenew, version, year)
 
 
-def convert(version: str, output: str, fwf: str, latex: Optional[str] = None) -> None:
-    latexes: List[StringOrIO] = [data.basepath / "pdgid_to_latexname.csv"]
+def convert(version: str, output: str, fwf: str, latex: str | None = None) -> None:
+    latexes: list[StringOrIO] = [data.basepath / "pdgid_to_latexname.csv"]
     if latex:
         latexes.append(latex)
     table = get_from_pdg_extended(fwf, latexes)
@@ -490,5 +492,5 @@ if __name__ == "__main__":
     )
     parser_convert.set_defaults(func=run_convert)
 
-    args = parser.parse_args()
-    args.func(args)
+    args_ = parser.parse_args()
+    args_.func(args_)
