@@ -4,25 +4,14 @@
 # or https://github.com/scikit-hep/particle for details.
 
 
+from __future__ import annotations
+
 # Python standard library
+import contextlib
 import csv
 from copy import copy
 from functools import total_ordering
-from typing import (
-    Any,
-    Callable,
-    Dict,
-    Iterable,
-    Iterator,
-    List,
-    Optional,
-    Sequence,
-    SupportsInt,
-    Tuple,
-    Type,
-    TypeVar,
-    Union,
-)
+from typing import Any, Callable, Iterable, Iterator, Sequence, SupportsInt, TypeVar
 
 # External dependencies
 import attr
@@ -50,7 +39,7 @@ from .utilities import latex_to_html_name, programmatic_name, str_with_unc
 __all__ = ("Particle", "ParticleNotFound", "InvalidParticle")
 
 
-def __dir__() -> Tuple[str, ...]:
+def __dir__() -> tuple[str, ...]:
     return __all__
 
 
@@ -62,8 +51,8 @@ class InvalidParticle(RuntimeError):
     pass
 
 
-def _isospin_converter(isospin: str) -> Optional[float]:
-    vals: Dict[Optional[str], Optional[float]] = {
+def _isospin_converter(isospin: str) -> float | None:
+    vals: dict[str | None, float | None] = {
         "0": 0.0,
         "1/2": 0.5,
         "1": 1.0,
@@ -72,13 +61,13 @@ def _isospin_converter(isospin: str) -> Optional[float]:
     return vals.get(isospin)
 
 
-def _none_or_positive_converter(value: float) -> Optional[float]:
+def _none_or_positive_converter(value: float) -> float | None:
     return None if value < 0 else value
 
 
 # These are needed to trick attrs typing
-minus_one: Optional[float] = -1.0
-none_float: Optional[float] = None
+minus_one: float | None = -1.0
+none_float: float | None = None
 
 
 Self = TypeVar("Self", bound="Particle")
@@ -192,22 +181,18 @@ class Particle:
 
     pdgid: PDGID = attr.ib(converter=PDGID)
     pdg_name: str = attr.ib()
-    mass: Optional[float] = attr.ib(minus_one, converter=_none_or_positive_converter)
-    mass_upper: Optional[float] = attr.ib(
+    mass: float | None = attr.ib(minus_one, converter=_none_or_positive_converter)
+    mass_upper: float | None = attr.ib(minus_one, converter=_none_or_positive_converter)
+    mass_lower: float | None = attr.ib(minus_one, converter=_none_or_positive_converter)
+    width: float | None = attr.ib(minus_one, converter=_none_or_positive_converter)
+    width_upper: float | None = attr.ib(
         minus_one, converter=_none_or_positive_converter
     )
-    mass_lower: Optional[float] = attr.ib(
+    width_lower: float | None = attr.ib(
         minus_one, converter=_none_or_positive_converter
     )
-    width: Optional[float] = attr.ib(minus_one, converter=_none_or_positive_converter)
-    width_upper: Optional[float] = attr.ib(
-        minus_one, converter=_none_or_positive_converter
-    )
-    width_lower: Optional[float] = attr.ib(
-        minus_one, converter=_none_or_positive_converter
-    )
-    _three_charge: Optional[Charge] = attr.ib(Charge.u, converter=Charge)  # charge * 3
-    I: Optional[float] = attr.ib(none_float, converter=_isospin_converter)  # noqa: E741
+    _three_charge: Charge | None = attr.ib(Charge.u, converter=Charge)  # charge * 3
+    I: float | None = attr.ib(none_float, converter=_isospin_converter)  # noqa: E741
     # J = attr.ib(None)  # Total angular momentum
     G = attr.ib(Parity.u, converter=Parity)  # Parity: '', +, -, or ?
     P = attr.ib(Parity.u, converter=Parity)  # Space parity
@@ -224,16 +209,16 @@ class Particle:
         return f'<{self.__class__.__name__}: name="{self}", pdgid={int(self.pdgid)}, mass={self._str_mass()}>'
 
     # Ordered loaded table of entries
-    _table: Optional[List["Particle"]] = None
+    _table: list[Particle] | None = None
 
     # Hash optimized table of particles
-    _hash_table: Optional[Dict[int, "Particle"]] = None
+    _hash_table: dict[int, Particle] | None = None
 
     # Names of loaded tables
-    _table_names: Optional[List[str]] = None
+    _table_names: list[str] | None = None
 
     @classmethod
-    def table_names(cls) -> Tuple[str, ...]:
+    def table_names(cls) -> tuple[str, ...]:
         """
         Return the list of names loaded.
 
@@ -250,8 +235,8 @@ class Particle:
 
         if cls._table_names is not None:
             return tuple(cls._table_names)  # make a copy to avoid user manipulation
-        else:
-            return tuple()
+
+        return ()
 
     @classmethod
     def table_loaded(cls) -> bool:
@@ -261,7 +246,7 @@ class Particle:
         return cls._table is not None
 
     @classmethod
-    def all(cls: Type[Self]) -> List[Self]:
+    def all(cls: type[Self]) -> list[Self]:
         """
         Access, hence get hold of, the internal particle data CSV table,
         loading it from the default location if no table has yet been loaded.
@@ -278,10 +263,10 @@ class Particle:
         exclusive_fields: Iterable[str] = (),
         exclude_fields: Iterable[str] = (),
         n_rows: int = -1,
-        filter_fn: Optional[Callable[["Particle"], bool]] = None,
-        particle: Optional[bool] = None,
+        filter_fn: Callable[[Particle], bool] | None = None,
+        particle: bool | None = None,
         **search_terms: Any,
-    ) -> Sequence[Sequence[Union[bool, int, float, str]]]:
+    ) -> Sequence[Sequence[bool | int | float | str]]:
         """
         Render a search (via `findall`) on the internal particle data CSV table
         as a `list`, loading the table from the default location if no table has yet been loaded.
@@ -396,10 +381,8 @@ class Particle:
             tbl_names = list_exclusive_fields
         else:
             for fld in exclude_fields:
-                try:
+                with contextlib.suppress(ValueError):
                     tbl_names.remove(fld)
-                except ValueError:
-                    pass
 
         # Start with the full table
         tbl_all = sorted(cls.all())
@@ -422,7 +405,7 @@ class Particle:
     @classmethod
     def to_dict(
         cls, *args: Any, **kwargs: Any
-    ) -> Dict[str, Tuple[Union[bool, int, str, float], ...]]:
+    ) -> dict[str, tuple[bool | int | str | float, ...]]:
         """
         Render a search (via `findall`) on the internal particle data CSV table
         as a `dict`, loading the table from the default location if no table has yet been loaded.
@@ -535,9 +518,9 @@ class Particle:
     @classmethod
     def load_table(
         cls,
-        filename: Optional[StringOrIO] = None,
+        filename: StringOrIO | None = None,
         append: bool = False,
-        _name: Optional[str] = None,
+        _name: str | None = None,
     ) -> None:
         """
         Load a particle data CSV table. Optionally append to the existing data already loaded if append=True.
@@ -561,12 +544,12 @@ class Particle:
         assert cls._table_names is not None
 
         if filename is None:
-            with data.basepath.joinpath("particle2021.csv").open() as fa:
-                cls.load_table(fa, append=append, _name="particle2021.csv")
+            with data.basepath.joinpath("particle2022.csv").open() as fa:
+                cls.load_table(fa, append=append, _name="particle2022.csv")
             with data.basepath.joinpath("nuclei2020.csv").open() as fb:
                 cls.load_table(fb, append=True, _name="nuclei2020.csv")
             return
-        elif isinstance(filename, HasRead):
+        if isinstance(filename, HasRead):
             tmp_name = _name or filename.name
             cls._table_names.append(tmp_name or f"{filename!r} {len(cls._table_names)}")
             open_file = filename
@@ -576,13 +559,13 @@ class Particle:
         else:
             cls._table_names.append(str(filename))
             assert not isinstance(filename, Traversable)
-            open_file = open(filename)
+            open_file = open(filename, encoding="utf_8")
 
         with open_file as f:
             r = csv.DictReader(line for line in f if not line.startswith("#"))
 
             for v in r:
-                try:
+                with contextlib.suppress(ValueError):
                     value = int(v["ID"])
 
                     p = cls(
@@ -609,27 +592,22 @@ class Particle:
                     # Replace the previous value if it exists
                     cls._hash_table[value] = p
 
-                except ValueError:
-                    pass
-
         cls._table = sorted(cls._hash_table.values())
 
     # The following __le__ and __eq__ needed for total ordering (sort, etc)
 
-    def __lt__(self, other: Union["Particle", int]) -> bool:
+    def __lt__(self, other: Particle | int) -> bool:
         # Sort by absolute particle numbers
         # The positive one should come first
         if isinstance(other, Particle):
             return abs(int(self.pdgid) - 0.25) < abs(int(other.pdgid) - 0.25)
         # Comparison with anything else should produce normal comparisons.
-        else:
-            return int(self.pdgid) < other
+        return int(self.pdgid) < other
 
     def __eq__(self, other: object) -> bool:
         if isinstance(other, Particle):
             return self.pdgid == other.pdgid
-        else:
-            return self.pdgid == other
+        return self.pdgid == other
 
     # Only one particle can exist per PDGID number
     def __hash__(self) -> int:
@@ -648,7 +626,7 @@ class Particle:
         return self.pdgid.J  # type: ignore[no-any-return]
 
     @property
-    def L(self) -> Optional[int]:
+    def L(self) -> int | None:
         """
         The orbital angular momentum L quantum number (None if not a meson).
 
@@ -658,7 +636,7 @@ class Particle:
         return self.pdgid.L  # type: ignore[no-any-return]
 
     @property
-    def S(self) -> Optional[int]:
+    def S(self) -> int | None:
         """
         The spin S quantum number (None if not a meson).
 
@@ -668,7 +646,7 @@ class Particle:
         return self.pdgid.S  # type: ignore[no-any-return]
 
     @property
-    def charge(self) -> Optional[float]:
+    def charge(self) -> float | None:
         """
         The particle charge, in units of the positron charge.
 
@@ -681,7 +659,7 @@ class Particle:
         return self.three_charge / 3 if self.three_charge is not None else None
 
     @property
-    def three_charge(self) -> Optional[int]:
+    def three_charge(self) -> int | None:
         "Three times the particle charge (charge * 3), in units of the positron charge."
         if not self.pdgid.is_nucleus:
             # Return int(...) not to return the actual enum Charge
@@ -690,11 +668,11 @@ class Particle:
                 if self._three_charge is not None and self._three_charge != Charge.u
                 else None
             )
-        else:
-            return self.pdgid.three_charge  # type: ignore[no-any-return]
+
+        return self.pdgid.three_charge  # type: ignore[no-any-return]
 
     @property
-    def lifetime(self) -> Optional[float]:
+    def lifetime(self) -> float | None:
         """
         The particle lifetime, in nanoseconds.
 
@@ -703,7 +681,7 @@ class Particle:
         return width_to_lifetime(self.width) if self.width is not None else None
 
     @property
-    def ctau(self) -> Optional[float]:
+    def ctau(self) -> float | None:
         """
         The particle c*tau, in millimeters.
 
@@ -738,15 +716,17 @@ class Particle:
         if self.pdgid.j_spin % 2 == 0:
             return SpinType.NonDefined
 
-        if self.J in [0, 1, 2]:
-            J = int(self.J)
-
+        J = int(self.J)
+        if J in {0, 1, 2}:
             if self.P == Parity.p:
                 return (SpinType.Scalar, SpinType.Axial, SpinType.Tensor)[J]
-            elif self.P == Parity.m:
-                return (SpinType.PseudoScalar, SpinType.Vector, SpinType.PseudoTensor)[
-                    J
-                ]
+            if self.P == Parity.m:
+                spin_types = (
+                    SpinType.PseudoScalar,
+                    SpinType.Vector,
+                    SpinType.PseudoTensor,
+                )
+                return spin_types[J]
 
         return SpinType.Unknown
 
@@ -781,15 +761,18 @@ class Particle:
         # Special case of the KS and KL
         if pid in {130, 310}:
             return False
+
         # I = 1 light mesons have no s-sbar component, hence has_strange == False
         if _digit(pid, Location.Nq3) == 1 and not pid.has_strange:
             return True
+
         # I = 0 light mesons have a s-sbar component, has_strange == True,
         # thought their net S = 0
-        elif _digit(pid, Location.Nq3) in {2, 3} and self.three_charge == 0:
+        if _digit(pid, Location.Nq3) in {2, 3} and self.three_charge == 0:
             return True
-        else:  # Only K-mesons at this point
-            return False
+
+        # Only K-mesons at this point
+        return False
 
     def invert(self: Self) -> Self:
         "Get the antiparticle."
@@ -797,8 +780,7 @@ class Particle:
             self.anti_flag == Inv.ChargeInv and self.three_charge != Charge.o
         ):
             return self.from_pdgid(-self.pdgid)
-        else:
-            return copy(self)
+        return copy(self)
 
     __neg__ = invert
     __invert__ = invert
@@ -830,11 +812,11 @@ class Particle:
         """
         if self.width is None:
             return "Width = None"
-        elif self.width == 0:
+        if self.width == 0:
             return "Width = 0.0 MeV"
-        elif self.width_lower is None or self.width_upper is None:
+        if self.width_lower is None or self.width_upper is None:
             return f"Width < {self.width} MeV"
-        elif (
+        if (
             self.width < 0.05
         ):  # corresponds to a lifetime of approximately 1.3e-20 seconds
             assert self.lifetime is not None
@@ -849,9 +831,9 @@ class Particle:
             e = width_to_lifetime(self.width - self.width_lower) - self.lifetime
             lifetime = str_with_unc(self.lifetime, e, e)
             return f"Lifetime = {lifetime} ns"
-        else:
-            width = str_with_unc(self.width, self.width_upper, self.width_lower)
-            return f"Width = {width} MeV"
+
+        width = str_with_unc(self.width, self.width_upper, self.width_lower)
+        return f"Width = {width} MeV"
 
     def _charge_in_name(self) -> bool:
         """Assess whether the particle charge is part of the particle name.
@@ -877,15 +859,16 @@ class Particle:
             # Quarkonia never exhibit the 0 charge
             # All eta, eta', h, h', omega, phi, f, f' light mesons are supposed to have an s-sbar component (see PDG site),
             # but some particles have pdgid.has_strange==False :S! Play it safe ...
-            elif any(
+            if any(
                 chr in self.pdg_name
                 for chr in ("eta", "h(", "h'(", "omega", "phi", "f", "f'")
             ):
                 return False
-            elif pid.has_strange or pid.has_charm or pid.has_bottom or pid.has_top:
+            if pid.has_strange or pid.has_charm or pid.has_bottom or pid.has_top:
                 return False
-            else:  # Light unflavoured mesons
-                return True
+
+            # Light unflavoured mesons
+            return True
         # Lambda baryons
         if (
             self.pdgid.is_baryon
@@ -909,10 +892,10 @@ class Particle:
         """
         if self._three_charge is None:
             return "None"
-        elif not self.pdgid.is_nucleus:
+        if not self.pdgid.is_nucleus:
             return Charge_undo[Charge(self._three_charge)]
-        else:
-            return str(self.pdgid.charge)
+
+        return str(self.pdgid.charge)
 
     def _str_mass(self) -> str:
         """
@@ -922,9 +905,9 @@ class Particle:
         """
         if self.mass is None:
             return "None"
-        else:
-            txt = str_with_unc(self.mass, self.mass_upper, self.mass_lower)
-            return f"{txt} MeV"
+
+        txt = str_with_unc(self.mass, self.mass_upper, self.mass_lower)
+        return f"{txt} MeV"
 
     def describe(self) -> str:
         "Make a nice high-density string for a particle's properties."
@@ -970,12 +953,12 @@ C (charge parity) = {C:<6}  I (isospin)       = {self.I!s:<7}  G (G-parity)
         return latex_to_html_name(self.latex_name)
 
     @classmethod
-    def empty(cls: Type[Self]) -> Self:
+    def empty(cls: type[Self]) -> Self:
         "Make a new empty particle."
         return cls(0, "Unknown", anti_flag=Inv.Same)
 
     @classmethod
-    def from_pdgid(cls: Type[Self], value: SupportsInt) -> Self:
+    def from_pdgid(cls: type[Self], value: SupportsInt) -> Self:
         """
         Get a particle from a PDGID. Uses by default the package
         extended PDG data table.
@@ -1001,7 +984,7 @@ C (charge parity) = {C:<6}  I (isospin)       = {self.I!s:<7}  G (G-parity)
             raise ParticleNotFound(f"Could not find PDGID {value}") from None
 
     @classmethod
-    def from_name(cls: Type[Self], name: str) -> Self:
+    def from_name(cls: type[Self], name: str) -> Self:
         """
         Get a particle from its name.
 
@@ -1019,7 +1002,7 @@ C (charge parity) = {C:<6}  I (isospin)       = {self.I!s:<7}  G (G-parity)
             raise ParticleNotFound(f'Could not find name "{name}"') from None
 
     @classmethod
-    def from_evtgen_name(cls: Type[Self], name: str) -> Self:
+    def from_evtgen_name(cls: type[Self], name: str) -> Self:
         """
         Get a particle from an EvtGen particle name, as in .dec decay files.
 
@@ -1032,12 +1015,85 @@ C (charge parity) = {C:<6}  I (isospin)       = {self.I!s:<7}  G (G-parity)
         """
         return cls.from_pdgid(EvtGenName2PDGIDBiMap[name])
 
+    @classmethod
+    def from_nucleus_info(
+        cls: type[Self],
+        z: int,
+        a: int,
+        anti: bool = False,
+        i: int = 0,
+        l_strange: int = 0,
+    ) -> Self:
+        """
+        Get a nucleus particle from the proton Z and atomic mass A numbers.
+
+        As described in the PDG numbering scheme:
+        "To avoid ambiguities, nucleus codes should not be applied to a single hadron, such as the p, n
+        or the Λ, where quark-contents-based codes already exist."
+
+        Number of neutrons is equal to a-z.
+        The PDG ID format is ±10LZZZAAAI, see the `is_nucleus()` function in submodule
+        `particle.pdgid.functions.py`.
+
+        Parameters
+        ----------
+        z: int
+            Atomic number Z (number of protons).
+            Maximum three decimal digits.
+        a: int
+            Atomic mass number A (total number of baryons).
+            Maximum three decimal digits.
+        anti: bool, optional, defaults to False (not antimatter).
+            Whether the nucleus should be antimatter.
+        i: int, optional, default is 0
+            Isomer level I. I=0 corresponds to the ground-state.
+            I>0 are excitations.
+            Maximum is one decimal digit.
+        l_strange: int, optional, default is 0
+            Total number of strange quarks.
+            Maximum is one decimal digit.
+
+        Raises
+        ------
+        ParticleNotFound
+            If `from_pdgid`, internally called, returns no match.
+        InvalidParticle
+            If the input combination is invalid.
+        """
+        if l_strange < 0 or l_strange > 9:
+            raise InvalidParticle(
+                f"Number of strange quarks l={l_strange} is invalid. Must be 0 <= l <= 9."
+            )
+        if z < 0 or z > 999:
+            raise InvalidParticle(
+                f"Atomic number Z={z} is invalid. Must be 0 <= A <= 999."
+            )
+        if a < 0 or a > 999:
+            raise InvalidParticle(
+                f"Atomic mass number A={a} is invalid. Must be 0 <= A <= 999."
+            )
+        if i < 0 or i > 9:
+            raise InvalidParticle(
+                f"Isomer level I={i} is invalid. Must be 0 <= I <= 9."
+            )
+        if z > a:
+            raise InvalidParticle(
+                f"Nucleus A={a}, Z={z} is invalid. Z must be smaller or equal to Z."
+            )
+
+        pdgid = int(1e9 + l_strange * 1e5 + z * 1e4 + a * 10 + i)
+
+        if anti:
+            return cls.from_pdgid(-pdgid)
+
+        return cls.from_pdgid(pdgid)
+
     @classmethod
     def finditer(
-        cls: Type[Self],
-        filter_fn: Union[Callable[["Particle"], bool], str, None] = None,
+        cls: type[Self],
+        filter_fn: Callable[[Particle], bool] | str | None = None,
         *,
-        particle: Optional[bool] = None,
+        particle: bool | None = None,
         **search_terms: Any,
     ) -> Iterator[Self]:
         """
@@ -1086,7 +1142,7 @@ C (charge parity) = {C:<6}  I (isospin)       = {self.I!s:<7}  G (G-parity)
             if particle is not None:
                 if particle and int(item.pdgid) < 0:
                     continue
-                elif (not particle) and int(item.pdgid) > 0:
+                if (not particle) and int(item.pdgid) > 0:
                     continue
 
             # If a filter function is passed, evaluate and skip if False
@@ -1129,12 +1185,12 @@ C (charge parity) = {C:<6}  I (isospin)       = {self.I!s:<7}  G (G-parity)
 
     @classmethod
     def findall(
-        cls: Type[Self],
-        filter_fn: Optional[Callable[["Particle"], bool]] = None,
+        cls: type[Self],
+        filter_fn: Callable[[Particle], bool] | None = None,
         *,
-        particle: Optional[bool] = None,
+        particle: bool | None = None,
         **search_terms: Any,
-    ) -> List[Self]:
+    ) -> list[Self]:
 
         """
         Search for a particle, returning a list of candidates.
@@ -1183,22 +1239,21 @@ C (charge parity) = {C:<6}  I (isospin)       = {self.I!s:<7}  G (G-parity)
         )
 
     @classmethod
-    def find(cls: Type[Self], *args: Any, **search_terms: Any) -> Self:
+    def find(cls: type[Self], *args: Any, **search_terms: Any) -> Self:
         raise AttributeError(
             "Method has been removed post versions 0.16. Please use finditer or findall instead."
         )
 
     @classmethod
-    def from_string(cls: Type[Self], name: str) -> Self:
+    def from_string(cls: type[Self], name: str) -> Self:
         "Get a particle from a PDG style name - returns the best match."
         matches = cls.from_string_list(name)
         if matches:
             return matches[0]
-        else:
-            raise ParticleNotFound(f"{name} not found in particle table")
+        raise ParticleNotFound(f"{name} not found in particle table")
 
     @classmethod
-    def from_string_list(cls: Type[Self], name: str) -> List[Self]:
+    def from_string_list(cls: type[Self], name: str) -> list[Self]:
         "Get a list of particles from a PDG style name."
 
         # Forcible override
@@ -1233,9 +1288,9 @@ C (charge parity) = {C:<6}  I (isospin)       = {self.I!s:<7}  G (G-parity)
             return []
 
     @classmethod
-    def _from_group_dict_list(cls: Type[Self], mat: Dict[str, Any]) -> List[Self]:
+    def _from_group_dict_list(cls: type[Self], mat: dict[str, Any]) -> list[Self]:
 
-        kw: Dict[str, Any] = {
+        kw: dict[str, Any] = {
             "particle": False
             if mat["bar"] is not None
             else True
