@@ -24,8 +24,10 @@ References
 """
 
 
+from __future__ import annotations
+
 from enum import IntEnum
-from typing import Optional, SupportsInt
+from typing import SupportsInt
 
 PDGID_TYPE = SupportsInt
 
@@ -249,7 +251,7 @@ def is_nucleus(pdgid: PDGID_TYPE) -> bool:
 
         if A_pdgid is None or Z_pdgid is None:
             return False
-        elif A_pdgid >= abs(Z_pdgid):
+        if A_pdgid >= abs(Z_pdgid):
             return True
     return False
 
@@ -512,19 +514,18 @@ def has_fundamental_anti(pdgid: PDGID_TYPE) -> bool:
     return False
 
 
-def charge(pdgid: PDGID_TYPE) -> Optional[float]:
+def charge(pdgid: PDGID_TYPE) -> float | None:
     """Returns the charge."""
 
     three_charge_pdgid = three_charge(pdgid)
     if three_charge_pdgid is None:
         return None
-    elif not is_Qball(pdgid):
+    if not is_Qball(pdgid):
         return three_charge_pdgid / 3.0
-    else:
-        return three_charge_pdgid / 30.0
+    return three_charge_pdgid / 30.0
 
 
-def three_charge(pdgid: PDGID_TYPE) -> Optional[int]:
+def three_charge(pdgid: PDGID_TYPE) -> int | None:
     """
     Returns 3 times the charge.
 
@@ -534,7 +535,7 @@ def three_charge(pdgid: PDGID_TYPE) -> Optional[int]:
         return None
 
     aid = abspid(pdgid)
-    charge = None
+    charge = None  # pylint: disable=redefined-outer-name
     ch100 = [
         -1,
         2,
@@ -647,9 +648,8 @@ def three_charge(pdgid: PDGID_TYPE) -> Optional[int]:
             Z_pdgid = Z(pdgid)
             if Z_pdgid is None:
                 return None
-            else:
-                return 3 * Z_pdgid
-        elif is_Qball(pdgid):  # Qball
+            return 3 * Z_pdgid
+        if is_Qball(pdgid):  # Qball
             charge = 3 * ((aid // 10) % 10000)
         else:  # this should never be reached in the present numbering scheme
             return None  # since extra bits exist only for Q-balls and nuclei
@@ -684,7 +684,7 @@ def three_charge(pdgid: PDGID_TYPE) -> Optional[int]:
     return charge
 
 
-def j_spin(pdgid: PDGID_TYPE) -> Optional[int]:
+def j_spin(pdgid: PDGID_TYPE) -> int | None:
     """Returns the total spin as 2J+1."""
     if not is_valid(pdgid):
         return None
@@ -699,22 +699,22 @@ def j_spin(pdgid: PDGID_TYPE) -> Optional[int]:
         if 20 < fund < 25:
             return 3
         return None
-    elif abs(int(pdgid)) in {1000000010, 1000010010}:  # neutron, proton
+    if abs(int(pdgid)) in {1000000010, 1000010010}:  # neutron, proton
         return 2
-    elif _extra_bits(pdgid) > 0:
+    if _extra_bits(pdgid) > 0:
         return None
     if pdgid in {130, 310}:
         return 1  # Special cases of the KS and KL !
     return abspid(pdgid) % 10
 
 
-def J(pdgid: PDGID_TYPE) -> Optional[float]:
+def J(pdgid: PDGID_TYPE) -> float | None:
     """Returns the total spin J."""
     value = j_spin(pdgid)
     return (value - 1) / 2 if value is not None else value
 
 
-def S(pdgid: PDGID_TYPE) -> Optional[int]:
+def S(pdgid: PDGID_TYPE) -> int | None:
     """
     Returns the spin S.
 
@@ -741,15 +741,15 @@ def S(pdgid: PDGID_TYPE) -> Optional[int]:
 
     if nl == 0:
         return 0 if js == 1 else 1
-    elif nl == 1:
+    if nl == 1:
         return 1 if js == 1 else 0
-    elif nl in {2, 3}:
+    if nl in {2, 3}:
         return 1 if js >= 3 else 0
-    else:
-        return 0
+
+    return 0
 
 
-def s_spin(pdgid: PDGID_TYPE) -> Optional[int]:
+def s_spin(pdgid: PDGID_TYPE) -> int | None:
     """
     Returns the spin S as 2S+1.
 
@@ -763,7 +763,7 @@ def s_spin(pdgid: PDGID_TYPE) -> Optional[int]:
     return (2 * value + 1) if value is not None else value
 
 
-def L(pdgid: PDGID_TYPE) -> Optional[int]:
+def L(pdgid: PDGID_TYPE) -> int | None:
     """
     Returns the orbital angular momentum L.
 
@@ -788,44 +788,44 @@ def L(pdgid: PDGID_TYPE) -> Optional[int]:
     if nl == 0:
         if js in {1, 3}:
             return 0
-        elif js == 5:
+        if js == 5:
             return 1
-        elif js == 7:
+        if js == 7:
             return 2
-        elif js == 9:
+        if js == 9:
             return 3
     elif nl == 1:
         if js in {1, 3}:
             return 1
-        elif js == 5:
+        if js == 5:
             return 2
-        elif js == 7:
+        if js == 7:
             return 3
-        elif js == 9:
+        if js == 9:
             return 4
     elif nl == 2:
         if js == 3:
             return 1
-        elif js == 5:
+        if js == 5:
             return 2
-        elif js == 7:
+        if js == 7:
             return 3
-        elif js == 9:
+        if js == 9:
             return 4
     elif nl == 3:
         if js == 3:
             return 2
-        elif js == 5:
+        if js == 5:
             return 3
-        elif js == 7:
+        if js == 7:
             return 4
-        elif js == 9:
+        if js == 9:
             return 5
 
     return 0
 
 
-def l_spin(pdgid: PDGID_TYPE) -> Optional[int]:
+def l_spin(pdgid: PDGID_TYPE) -> int | None:
     """
     Returns the orbital angular momentum L as 2L+1.
 
@@ -839,8 +839,13 @@ def l_spin(pdgid: PDGID_TYPE) -> Optional[int]:
     return (2 * value + 1) if value is not None else value
 
 
-def A(pdgid: PDGID_TYPE) -> Optional[int]:
-    """Returns the atomic number A if the PDG ID corresponds to a nucleus. Else it returns None."""
+def A(pdgid: PDGID_TYPE) -> int | None:
+    """
+    Returns the atomic mass number A if the PDG ID corresponds to a nucleus, else it returns None.
+
+    The (atomic) mass number is also known as the nucleon number, the total number of protons and neutrons.
+    The number of neutrons is hence N = A - Z.
+    """
     # A proton can be a Hydrogen nucleus
     # A neutron can be considered as a nucleus when given the PDG ID 1000000010,
     # hence consistency demands that A(neutron) = 1
@@ -851,8 +856,13 @@ def A(pdgid: PDGID_TYPE) -> Optional[int]:
     return (abspid(pdgid) // 10) % 1000
 
 
-def Z(pdgid: PDGID_TYPE) -> Optional[int]:
-    """Returns the charge Z if the PDG ID corresponds to a nucleus. Else it returns None."""
+def Z(pdgid: PDGID_TYPE) -> int | None:
+    """
+    Returns the nuclear charge Z if the PDG ID corresponds to a nucleus, else it returns None.
+
+    The nuclear charge number Z is also known as the atomic number.
+    For ordinary nuclei Z is equal to the number of protons.
+    """
     # A proton can be a Hydrogen nucleus
     if abspid(pdgid) == 2212:
         return int(pdgid) // 2212
@@ -897,10 +907,9 @@ def _fundamental_id(pdgid: PDGID_TYPE) -> int:
         return 0
     if abspid(pdgid) <= 100:
         return abspid(pdgid)
-    elif _digit(pdgid, Location.Nq2) == 0 and _digit(pdgid, Location.Nq1) == 0:
+    if _digit(pdgid, Location.Nq2) == _digit(pdgid, Location.Nq1) == 0:
         return abspid(pdgid) % 10000
-    else:
-        return 0
+    return 0
 
 
 def _has_quark_q(pdgid: PDGID_TYPE, q: int) -> bool:
@@ -916,7 +925,7 @@ def _has_quark_q(pdgid: PDGID_TYPE, q: int) -> bool:
     if is_nucleus(pdgid):
         if q in {1, 2}:
             return True  # Nuclei by construction contain up and down quarks
-        elif q == 3 and pdgid not in {2112, 2212}:
+        if q == 3 and pdgid not in {2112, 2212}:
             return _digit(pdgid, Location.N8) > 0
     if _extra_bits(pdgid) > 0:
         return False
