@@ -4,6 +4,8 @@
 # or https://github.com/scikit-hep/particle for details.
 
 
+from __future__ import annotations
+
 import pytest
 from hepunits import meter, second
 from pytest import approx
@@ -145,6 +147,27 @@ def test_pdg_convert():
     assert int(p.pdgid) == 211
 
 
+def test_nucleus_convert():
+    p = Particle.from_nucleus_info(1, 2)
+    assert p.pdgid == 1000010020
+    p = Particle.from_nucleus_info(92, 235)
+    assert p.pdgid == 1000922350
+    p = Particle.from_nucleus_info(1, 2, anti=True)
+    assert p.pdgid == -1000010020
+    # No exited nuclei in database
+    try:
+        p = Particle.from_nucleus_info(1, 2, i=1)
+        assert p.pdgid == 1000010021
+    except ParticleNotFound:
+        pass
+    # No strange nuclei in database and strange PDGID not implemented
+    try:
+        p = Particle.from_nucleus_info(1, 2, l_strange=1)
+        assert p.pdgid == 1100010020
+    except ParticleNotFound and InvalidParticle:
+        pass
+
+
 def test_sorting():
     assert Particle.from_pdgid(211) < Particle.from_pdgid(311)
     assert Particle.from_pdgid(211) < Particle.from_pdgid(-311)
@@ -308,8 +331,6 @@ checklist_describe = (
     [423, "Width < 2.1 MeV"],  # D*(2007)0
     [10431, "Width < 10.0 MeV"],  # D(s0)*(2317)+
     [20433, "Width < 6.3 MeV"],  # D(s1)(2460)+
-    [4212, "Width < 4.6 MeV"],  # Sigma(c)(2455)+
-    [4214, "Width < 17.0 MeV"],  # Sigma(c)(2520)+
 )
 
 
@@ -320,18 +341,18 @@ def test_describe(pid, description):
 
 
 def test_default_table_loading():
-    assert Particle.table_names() == ("particle2021.csv", "nuclei2020.csv")
+    assert Particle.table_names() == ("particle2022.csv", "nuclei2020.csv")
 
 
 def test_default_table_loading_bis():
     Particle.all()
     p = Particle.from_pdgid(211)
     assert p.table_loaded() is True
-    assert p.table_names() == ("particle2021.csv", "nuclei2020.csv")
+    assert p.table_names() == ("particle2022.csv", "nuclei2020.csv")
 
 
 def test_explicit_table_loading():
-    Particle.load_table(data.basepath / "particle2021.csv")
+    Particle.load_table(data.basepath / "particle2022.csv")
     assert Particle.table_loaded()
     assert len(Particle.table_names()) == 1
     assert Particle.all() is not None
@@ -346,6 +367,8 @@ def test_all_particles_are_loaded():
     assert len(Particle.all()) == 610
     Particle.load_table(data.basepath / "particle2021.csv")
     assert len(Particle.all()) == 616
+    Particle.load_table(data.basepath / "particle2022.csv")
+    assert len(Particle.all()) == 616
 
     Particle.load_table(data.basepath / "nuclei2020.csv")
     assert len(Particle.all()) == 5880
